## START: Set by rpmautospec
## (rpmautospec version 0.8.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 3;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global common_description %{expand:
The Trio project's goal is to produce a production-quality, permissively
licensed, async/await-native I/O library for Python.  Like all async libraries,
its main purpose is to help you write programs that do multiple things at the
same time with parallelized I/O.  A web spider that wants to fetch lots of
pages in parallel, a web server that needs to juggle lots of downloads and
websocket connections at the same time, a process supervisor monitoring
multiple subprocesses... that sort of thing.  Compared to other libraries, Trio
attempts to distinguish itself with an obsessive focus on usability and
correctness.  Concurrency is complicated; we try to make it easy to get things
right.}


Name:           python-trio
Version:        0.29.0
Release:        %autorelease
Summary:        A friendly Python library for async concurrency and I/O
License:        Apache-2.0 OR MIT
URL:            https://github.com/python-trio/trio
Source:         %pypi_source trio

# Add xfail to test_ki_protection_doesnt_leave_cyclic_garbage on Python 3.14
# https://github.com/python-trio/trio/pull/3211/commits/02b338ebab972ffe16bca14bdd5823db9ab61631
#
# From:
#
# Add xfail for issue 3209, and start testing Python 3.14
# https://github.com/python-trio/trio/pull/3211
#
# See:
#
# Python 3.14: test_ki_protection_doesnt_leave_cyclic_garbage fails
# https://github.com/python-trio/trio/issues/3209
#
# The root cause appears to be:
#
# [3.14] change in behaviour in gc.get_referrers(some_local)
# https://github.com/python/cpython/issues/125603
#
# Fixes:
#
# python-trio fails to build with Python 3.14:
# test_ki_protection_doesnt_leave_cyclic_garbage: Left contains one more item:
# <coroutine object test_ki_protection_doesnt_leave_cyclic_garbage at
# 0x7fbaa2f162c0>
# https://bugzilla.redhat.com/show_bug.cgi?id=2345516
Patch:          %{url}/pull/3211/commits/02b338ebab972ffe16bca14bdd5823db9ab61631.patch

# Switch from PurePath#as_uri to PurePath#joinpath for our test that PurePath methods get inherited
# Restore trio.Path#as_uri
Patch:          %{url}/pull/3249.patch

BuildArch:      noarch


%description %{common_description}


%package -n python3-trio
Summary:        %{summary}
BuildRequires:  python3-devel
BuildRequires:  python3-pytest


%description -n python3-trio %{common_description}


%prep
%autosetup -p 1 -n trio-%{version}


%generate_buildrequires
%pyproject_buildrequires


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files -l trio


%check
# https://github.com/python-trio/trio/issues/2863
# https://docs.pytest.org/en/stable/explanation/goodpractices.html#tests-as-part-of-application-code
%pytest \
%if %{defined el10}
    --import-mode=append \
%endif
    --pyargs trio \
    --verbose \
    --skip-optional-imports


%files -n python3-trio -f %{pyproject_files}
%doc README.rst


%changelog
## START: Generated by rpmautospec
* Thu May 22 2025 Miro Hrončok <miro@hroncok.cz> - 0.29.0-3
- Fix one test failure on Python 3.14.0b1

* Fri Feb 14 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.29.0-2
- Backport xfail for one test in Python 3.14 (close RHBZ#2345516)

* Fri Feb 14 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.29.0-1
- Update to 0.29.0 (close RHBZ#2345683)

* Wed Feb 12 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.28.0-2
- Add a small workaround for pytest 7 in EPEL10

* Tue Feb 11 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.28.0-1
- Update to 0.28.0 (close RHBZ#2254476)

* Tue Feb 11 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.26.2-2
- Assert that .dist-info contains a license file

* Mon Feb 10 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.26.2-1
- Update to 0.26.2

* Mon Feb 10 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.26.0-1
- Update to 0.26.0

* Mon Feb 10 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.25.1-1
- Update to 0.25.1

* Mon Jan 20 2025 Fedora Release Engineering <releng@fedoraproject.org> - 0.23.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.23.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Fri Jun 07 2024 Python Maint <python-maint@redhat.com> - 0.23.1-5
- Rebuilt for Python 3.13

* Mon May 27 2024 Miro Hrončok <miro@hroncok.cz> - 0.23.1-4
- Python 3.13 support

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.23.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.23.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Tue Nov 07 2023 Carl George <carlwgeorge@fedoraproject.org> - 0.23.1-1
- Update to version 0.23.1, resolves rhbz#2219110

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.22.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Sat Jul 01 2023 Python Maint <python-maint@redhat.com> - 0.22.0-4
- Rebuilt for Python 3.12

* Sat Jul 01 2023 Miro Hrončok <mhroncok@redhat.com> - 0.22.0-3
- Remove async_generator as dependency

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.22.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Oct 31 2022 Carl George <carl@george.computer> - 0.22.0-1
- Update to 0.22.0, resolves rhbz#2094511

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.20.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jun 13 2022 Python Maint <python-maint@redhat.com> - 0.20.0-4
- Rebuilt for Python 3.11

* Thu Mar 24 2022 Miro Hrončok <mhroncok@redhat.com> - 0.20.0-3
- Add fix for Python 3.11
- Fixes: rhbz#2049632

* Thu Mar 03 2022 Carl George <carl@george.computer> - 0.20.0-1
- Latest upstream rhbz#2056578

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.19.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sat Jul 24 2021 Carl George <carl@george.computer> - 0.19.0-1
- Latest upstream rhbz#1972135

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 0.18.0^20210519gitd883dbe-4
- Rebuilt for Python 3.10

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 0.18.0^20210519gitd883dbe-3
- Bootstrap for Python 3.10

* Mon May 17 2021 Tomas Hrnciar <thrnciar@redhat.com> - 0.18.0-2
- Backport upstream fixes to bring compatibility with Python 3.10

* Tue Feb 09 2021 Joel Capitao <jcapitao@redhat.com> - 0.18.0-1
- Latest upstream rhbz#1879061

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.16.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sun Sep 06 2020 Carl George <carl@george.computer> - 0.16.0-1
- Latest upstream

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jun 04 2020 Carl George <carl@george.computer> - 0.15.1-1
- Latest upstream rhbz#1828266

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 0.13.0-3
- Rebuilt for Python 3.9

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.13.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jan 02 2020 Carl George <carl@george.computer> - 0.13.0-1
- Latest upstream rhbz#1742425

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 0.11.0-4
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 0.11.0-3
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.11.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu Feb 28 2019 Carl George <carl@george.computer> - 0.11.0-1
- Latest upstream

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Sep 20 2018 Carl George <carl@george.computer> - 0.7.0-1
- Initial package

## END: Generated by rpmautospec
